@@ -8,6 +8,8 @@ use core::{convert::TryFrom, str::FromStr};
 
 #[cfg(feature = "alloc")]
 extern crate alloc;
+#[cfg(feature = "alloc")]
+use alloc::string::ToString;
 
 #[cfg(feature = "use_serde")]
 use serde::{Deserialize, Serialize};
@@ -136,10 +138,16 @@ impl Default for ClientSettings {
     }
 }
 
+#[derive(Clone, Debug, PartialEq, Default)]
+#[cfg_attr(feature = "use_serde", derive(Serialize, Deserialize))]
+pub struct DHCPClientSettings {
+    pub hostname: Option<String>,
+}
+
 #[derive(Clone, Debug, PartialEq)]
 #[cfg_attr(feature = "use_serde", derive(Serialize, Deserialize))]
 pub enum ClientConfiguration {
-    DHCP,
+    DHCP(DHCPClientSettings),
     Fixed(ClientSettings),
 }
 
@@ -164,7 +172,7 @@ impl ClientConfiguration {
 
 impl Default for ClientConfiguration {
     fn default() -> ClientConfiguration {
-        ClientConfiguration::DHCP
+        ClientConfiguration::DHCP(Default::default())
     }
 }
 
