@@ -1,8 +1,8 @@
 use core::fmt::Debug;
 use core::mem;
 
-#[cfg(feature = "alloc")]
 extern crate alloc;
+use alloc::boxed::Box;
 
 use enumset::*;
 
@@ -229,7 +229,7 @@ impl ClientConfiguration {
             return ip_conf;
         }
 
-        *ip_conf = Some(ipv4::ClientConfiguration::DHCP);
+        *ip_conf = Some(ipv4::ClientConfiguration::DHCP(Default::default()));
         Self::to_ip_conf(ip_conf)
     }
 }
@@ -539,7 +539,11 @@ impl Status {
 }
 
 pub trait Wifi {
-    type Error;
+    #[cfg(not(feature = "std"))]
+    type Error: core::fmt::Debug + core::fmt::Display;
+
+    #[cfg(feature = "std")]
+    type Error: std::error::Error + Send + Sync + 'static;
 
     fn get_capabilities(&self) -> Result<EnumSet<Capability>, Self::Error>;
 
@@ -570,7 +574,11 @@ pub trait Wifi {
 
 #[async_trait]
 pub trait WifiAsync {
-    type Error;
+    #[cfg(not(feature = "std"))]
+    type Error: core::fmt::Debug + core::fmt::Display;
+
+    #[cfg(feature = "std")]
+    type Error: std::error::Error + Send + Sync + 'static;
 
     async fn get_capabilities(&self) -> Result<EnumSet<Capability>, Self::Error>;
 
